SystemOrganization addCategory: #'MC2-Tests-Repository-Network'!

MDRepositoryTest subclass: #MDNetRepositoryTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDNetRepositoryTest methodsFor: 'as yet unclassified' stamp: 'cwp 1/8/2008 18:00'!
newRepository
	^ MDFakeLink repositoryForTesting ! !

MDTestCase subclass: #MDNetClientTest
	instanceVariableNames: 'link repository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDNetClientTest methodsFor: 'running' stamp: 'cwp 5/22/2008 00:11'!
setUp
	link := MDMockLink new.
	repository := MDNetRepository link: link! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 14:15'!
testClose
	link
		open;
		expect: (MDGoodbye new);
		inject: (MDGoodbye new).
	repository close.
	self deny: link isOpen! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 20:51'!
testCloseProtocolError
	
	link
		open;
		expect: (MDGoodbye new);
		inject: (MDHello new).
	
	self
		should: [repository close]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 14:20'!
testDescription
	self assert: repository description = 'Mock'! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGet
	| version result |
	version := self version.
	link
		open;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: {version}).
	result := repository get: version hashstamp.
	self assert: result = version.
! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGetAll
	| version result |
	version := self version.
	link
		open;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: {version}).
	result := repository getAll: {version hashstamp}.
	self assert: result anyOne = version.
! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGetAllNotFound
	| version result |
	version := self version.
	link
		open;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: #()).
	result := repository getAll: {version hashstamp}.
	self assert: result isEmpty! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGetAllProtocolError
	| version |
	version := self version.
	link
		open;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDGoodbye new).
	
	self
		should: [repository getAll: {version hashstamp}]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGetNotFound
	| version result |
	version := self version.
	link
		open;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: #()).
	result := repository get: version hashstamp.
	self assert: result isNil! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGetProtocolError
	
	| hashstamp |
	hashstamp := self version hashstamp.
	link
		open;
		expect: (MDGetObjects with: {hashstamp});
		inject: (MDGoodbye new).
	
	self
		should: [repository get: hashstamp]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testGetSome
	| a b result |
	a := self versionWith: #a.
	b := self versionWith: #b.
	link
		open;
		expect: (MDGetObjects with: {a hashstamp. b hashstamp});
		inject: (MDObjects with: {a}).
	result := repository getAll: {a hashstamp. b hashstamp}.
	self assert: result size = 1.
	self assert: result anyOne = a! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testHashstamps
	| memo result |
	memo := self memo.
	link
		open;
		expect: (MDGetHashstamps new);
		inject: (MDAllHashstamps with: {memo}).
	result := repository allHashstamps.
	self assert: result size = 1.
	self assert: result anyOne = memo! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 20:52'!
testHelloProtocolError
	
	link
		expect: (MDHello new);
		inject: (MDGoodbye new).
	
	self
		should: [repository memos]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testImplicitOpen
	| version |
	version := self version.
	link
		expect: MDHello new;
		inject: MDHello new;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: {version}).
	repository get: version hashstamp.! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testImplicitReopen
	| version |
	version := self version.
	link
		open;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: {version}).
	repository get: version hashstamp.
	link 
		close;
		expect: MDHello new;
		inject: MDHello new;
		expect: (MDGetObjects with: {version hashstamp});
		inject: (MDObjects with: {version}).
	repository get: version hashstamp.! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testMemos
	| memo result |
	memo := self memo.
	link
		open;
		expect: (MDGetMemos new);
		inject: (MDMemos with: {memo}).
	result := repository memos.
	self assert: result size = 1.
	self assert: result anyOne = memo! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 20:50'!
testMemosProtocolError
	
	link
		open;
		expect: (MDGetMemos new);
		inject: (MDHello new).
	
	self
		should: [repository memos]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPut
	| version |
	version := self version.
	link
		open;
		expect: (MDPutObjects with: {version});
		inject: (MDThankYou with: 1).
	repository put: version.
	! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutAll
	| version |
	version := self version.
	link
		open;
		expect: (MDOfferObjects with: {version hashstamp});
		inject: (MDRequestObjects with: {version hashstamp});
		expect: (MDPutObjects with: {version});
		inject: (MDThankYou with: 1).
	repository putAll: {version}.
	! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutAllFailed
	| version |
	version := self version.
	link
		open;
		expect: (MDOfferObjects with: {version hashstamp});
		inject: (MDRequestObjects with: {version hashstamp});
		expect: (MDPutObjects with: {version});
		inject: (MDStorageFailed with: 'Just testing').
	self 
		should: [repository putAll: {version}]
		raise: MDPeerError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutAllProtocolError1
	| version |
	version := self version.
	link
		open;
		expect: (MDOfferObjects with: {version hashstamp});
		inject: (MDThankYou new).
	self
		should: [repository putAll: {version}]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutAllProtocolError2
	| version |
	version := self version.
	link
		open;
		expect: (MDOfferObjects with: {version hashstamp});
		inject: (MDRequestObjects with: {version hashstamp});
		expect: (MDPutObjects with: {version});
		inject: (MDHello new).
	self
		should: [repository putAll: {version}]
		raise: MDProtocolError
	! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutFailed
	| version |
	version := self version.
	link
		open;
		expect: (MDPutObjects with: {version});
		inject: (MDStorageFailed with: 'Just testing').
	
	self
		should: [repository put: version]
		raise: MDPeerError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutNone
	| a b |
	a := self versionWith: #a.
	b := self versionWith: #b.
	link
		open;
		expect: (MDOfferObjects with: {a hashstamp. b hashstamp});
		inject: (MDRequestObjects with: #()).
	repository putAll: {a. b}.
	link
		close
		expect: (MDGoodbye new);
		inject: (MDGoodbye new).
	repository close! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 8/9/2009 01:11'!
testPutProtocolError
	| version |
	version := self version.
	link
		open;
		expect: (MDPutObjects with: {version});
		inject: (MDHello new).
	
	self 
		should: [repository put: version]
		raise: MDProtocolError! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testPutSome
	| a b |
	a := self versionWith: #a.
	b := self versionWith: #b.
	link
		open;
		expect: (MDOfferObjects with: {a hashstamp. b hashstamp});
		inject: (MDRequestObjects with: {a hashstamp});
		expect: (MDPutObjects with: {a});
		inject: (MDThankYou with: 1).
	repository putAll: {a. b}.
	! !

!MDNetClientTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testSelectFrom
	| hashstamp result |
	hashstamp := self version hashstamp.
	link
		open;
		expect: (MDOfferObjects with: {hashstamp});
		inject: (MDRequestObjects with: {hashstamp}).
		
	result := repository selectFrom: {hashstamp} asSet.
	self assert: result size = 1.
	self assert: result anyOne = hashstamp! !

MDTestCase subclass: #MDNetLinkTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDNetLinkTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testClose
	| link |
	link := MDNetLink locator: (MDFakeLocator new).
	link open.
	link locator mocket 
		execute: [link close];
		expectClose;
		done.! !

!MDNetLinkTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testDescription
	| link |
	link := MDNetLink locator: (MDFakeLocator new).
	self assert: link description = 'Fake'! !

!MDNetLinkTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testOpen
	| link |
	link := MDNetLink locator: (MDFakeLocator new).
	link open.
	self assert: link isOpen.
	self assert: link locator mocket isConnected.! !

!MDNetLinkTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testSend
	| link mocket msg |
	link := MDNetLink locator: (MDFakeLocator new).
	mocket := link locator mocket.
	msg := MDHello with: 'test'.
	mocket
		execute: [link open; send: msg];
		expect: msg bytes;
		done! !

!MDNetLinkTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testSendBeforeOpen
	| link msg |
	link := MDNetLink locator: (MDFakeLocator new).
	msg := MDHello with: 'test'.
	self 
		should: [link send: msg]
		raise: Error! !

!MDNetLinkTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testSendResponse
	| link mocket msg result |
	link := MDNetLink locator: (MDFakeLocator new).
	mocket := link locator mocket.
	msg := MDHello with: 'test'.
	mocket
		execute: 
			[link open.
			result := link send: msg.
			self assert: result class = MDHello];
		expect: msg bytes;
		inject: msg bytes! !

MDTestCase subclass: #MDNetSerializationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDNetSerializationTest methodsFor: 'asserting' stamp: 'cwp 5/22/2008 00:11'!
assertEqualityOf: anObject
	| bytes other |
	bytes := anObject bytes.
	other := MDNetMessage fromBytes: bytes.
	self assert: anObject = other! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:30'!
testAuthenticationFailed
	self assertEqualityOf: (MDAuthenticationFailed with: 'Unknown user')! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/8/2008 18:38'!
testGetHashstamps
	self assertEqualityOf: MDGetHashstamps new! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/3/2008 23:32'!
testGetMemos
	self assertEqualityOf: MDGetMemos new! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/3/2008 23:25'!
testGetObjects
	self assertEqualityOf: (MDGetObjects with: (Set with: self version hashstamp))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:40'!
testGoodbye
	self assertEqualityOf: (MDGoodbye with: 'colin@wiresong.ca')! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/8/2008 18:17'!
testHashstamps
	self assertEqualityOf: (MDAllHashstamps with: (Set with: self version hashstamp))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:37'!
testHello
	self assertEqualityOf: (MDHello with: 'colin@wiresong.ca')! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 5/22/2008 00:11'!
testIdConflict
	| messages others |
	messages := MDNetMessage allSubclasses select: [:ea | ea isConcrete].
	messages do:
		[:msg |
		others := messages copyWithout: msg.
		others do: [:other | self deny: msg id = other id]]! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:09'!
testMemos
	self assertEqualityOf: (MDMemos with: (Set with: self memo))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:34'!
testObjectNotFound
	self assertEqualityOf: (MDStorageFailed with: 'Disk full')! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:08'!
testObjects
	self assertEqualityOf: (MDObjects with: (Set with: self version))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:23'!
testOfferObjects
	self assertEqualityOf: (MDOfferObjects with: (Set with: self version hashstamp))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:07'!
testPutObjects
	self assertEqualityOf: (MDPutObjects with: (Set with: self version))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:23'!
testRequestObjects
	self assertEqualityOf: (MDRequestObjects with: (Set with: self version hashstamp))! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/3/2008 23:53'!
testThankYou
	self assertEqualityOf: (MDThankYou with: 4)! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:31'!
testUnauthorized
	self assertEqualityOf: (MDUnauthorized with: 'That version is private')! !

!MDNetSerializationTest methodsFor: 'tests' stamp: 'cwp 1/4/2008 00:26'!
testUnrecognizedMessage
	self assertEqualityOf: (MDUnrecognizedMessage with: 'Message id 555 not implemented')! !

MDTestCase subclass: #MDNetServiceTest
	instanceVariableNames: 'service repository'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
setUp
	repository := MDMemoryRepository new.
	service := MDNetService for: repository.! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testGetMemos
	| memo result |
	memo := self memo.
	repository put: memo.
	result := service handleMessage: (MDGetMemos new).
	self assert: result isMemos.
	self assert: (result objects includes: memo)! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testGetNotFound
	| a b result |
	a := self versionWith: #a.
	b := self versionWith: #b.
	repository put: b.
	result := service handleMessage: (MDGetObjects with: {a hashstamp. b hashstamp}).
	self assert: result isObjects.
	self assert: result objects size = 1.
	self assert: result objects anyOne = b.! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testGetObjects
	| version result |
	version := self version.
	repository put: version.
	result := service handleMessage: (MDGetObjects with: {version hashstamp}).
	self assert: result isObjects.
	self assert: (result objects includes: version)! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testGetPartial
	| version result |
	version := self version.
	result := service handleMessage: (MDGetObjects with: {version hashstamp}).
	self assert: result isObjects.
	self assert: result objects isEmpty! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testGoodbye
	| result |
	result := service handleMessage: MDGoodbye new.
	self assert: result isGoodbye! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testHello
	
	| result |
	result := service handleMessage: MDHello new.
	self assert: result isHello.
! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testOfferObjects
	| result a b |
	a := self versionWith: #a.
	b := self versionWith: #b.
	repository put: a.
	result := service handleMessage: (MDOfferObjects with: {a hashstamp. b hashstamp}).
	self assert: result isRequestObjects.
	self assert: result hashstamps size = 1.
	self assert: result hashstamps anyOne = b hashstamp.! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testOfferObjectsUnneeded
	| result version |
	version := self version.
	repository put: version.
	result := service handleMessage: (MDOfferObjects with: {version hashstamp}).
	self assert: result isRequestObjects.
	self assert: result hashstamps isEmpty! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testPutObjects
	| version result |
	version := self version.
	result := service handleMessage: (MDPutObjects with: {version}).
	self assert: result isThankYou.
	self assert: (repository get: version hashstamp) = version! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testPutObjectsFailed
	| version result |
	version := self version.
	service instVarNamed: 'repository' put: nil.
	result := service handleMessage: (MDPutObjects with: {version}).
	self assert: result class = MDStorageFailed.
	self assert: result description = 'MessageNotUnderstood: UndefinedObject>>putAll:'! !

!MDNetServiceTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testServerError
	| version result |
	version := self version.
	service instVarNamed: 'repository' put: nil.
	result := service handleMessage: (MDGetObjects with: {version hashstamp}).
	self assert: result class = MDProcessingError.
	self assert: result description = 'MessageNotUnderstood: UndefinedObject>>getAll:'! !

Object subclass: #MDFakeLink
	instanceVariableNames: 'service closed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDFakeLink class methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
repositoryForTesting
	| service link repository |
	service := MDNetService for: MDMemoryRepository new.
	link := MDFakeLink to: service.
	repository := MDNetRepository link: link.
	^ repository! !

!MDFakeLink class methodsFor: 'as yet unclassified' stamp: 'cwp 1/4/2008 23:58'!
to: aService
	^ self new setService: aService! !

!MDFakeLink methodsFor: 'accessing' stamp: 'jf 10/25/2008 13:35'!
close
	closed := true! !

!MDFakeLink methodsFor: 'accessing' stamp: 'cwp 1/5/2008 00:10'!
description
	^ 'fake net repository'! !

!MDFakeLink methodsFor: 'testing' stamp: 'jf 10/25/2008 13:36'!
isOpen
	^ closed isNil or: [ closed not ]! !

!MDFakeLink methodsFor: 'accessing' stamp: 'cwp 6/1/2008 00:55'!
locator
	^ MDFakeLocator new! !

!MDFakeLink methodsFor: 'as yet unclassified' stamp: 'cwp 1/4/2008 23:58'!
send: aMessage
	^ service handleMessage: aMessage! !

!MDFakeLink methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
setService: aService
	service := aService! !

Object subclass: #MDFakeLocator
	instanceVariableNames: 'stream mocket'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDFakeLocator methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
createStream
	| class |
	class := Smalltalk at: #FastSocketStream ifAbsent: [Smalltalk at: #SocketStream].
	stream := class on: self mocket.
	^ stream! !

!MDFakeLocator methodsFor: 'as yet unclassified' stamp: 'cwp 1/12/2008 13:03'!
description
	^ 'Fake'! !

!MDFakeLocator methodsFor: 'as yet unclassified' stamp: 'cwp 6/1/2008 00:34'!
host
	^ 'fakehost.com'! !

!MDFakeLocator methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
mocket
	
	^ mocket ifNil: 
		[mocket := MLMocket new.
		mocket
			execute: [mocket connectTo: #(127 0 0 1) port: 7301];
			expectConnectionTo: #(127 0 0 1) port: 7301]! !

!MDFakeLocator methodsFor: 'as yet unclassified' stamp: 'cwp 6/1/2008 00:36'!
port
	^ 7901! !

!MDFakeLocator methodsFor: 'as yet unclassified' stamp: 'jf 11/8/2009 17:25'!
update: properties
	^ properties
		host: self host;
		port: self port;
		yourself! !

Object subclass: #MDMockLink
	instanceVariableNames: 'injected expected open'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDMockLink class methodsFor: 'as yet unclassified' stamp: 'cwp 11/20/2008 18:51'!
new
	^ self basicNew initialize! !

!MDMockLink methodsFor: 'asserting' stamp: 'cwp 1/4/2008 12:32'!
assert: actual matches: expectation
	actual = expectation ifFalse: [TestFailure signal: 'Unexpected message']! !

!MDMockLink methodsFor: 'open/close' stamp: 'cwp 5/22/2008 00:11'!
close
	open := false! !

!MDMockLink methodsFor: 'accessing' stamp: 'cwp 1/4/2008 14:19'!
description
	^ 'Mock'! !

!MDMockLink methodsFor: 'asserting' stamp: 'cwp 1/4/2008 12:26'!
expect: aMessage
	expected add: aMessage! !

!MDMockLink methodsFor: 'initialize-release' stamp: 'cwp 5/22/2008 00:11'!
initialize
	injected := OrderedCollection new.
	expected := OrderedCollection new.
	open := false! !

!MDMockLink methodsFor: 'asserting' stamp: 'cwp 1/4/2008 12:25'!
inject: aMessage
	injected add: aMessage! !

!MDMockLink methodsFor: 'open/close' stamp: 'cwp 1/4/2008 12:33'!
isOpen
	^ open! !

!MDMockLink methodsFor: 'accessing' stamp: 'cwp 6/5/2008 07:17'!
locator
	^ MDNetLocator host: 'example.com' port: 7901! !

!MDMockLink methodsFor: 'open/close' stamp: 'cwp 5/22/2008 00:11'!
open
	open := true! !

!MDMockLink methodsFor: 'sending' stamp: 'cwp 1/4/2008 12:31'!
send: aMessage
	self assert: aMessage matches: expected removeFirst.
	^ injected removeFirst! !

TestCase subclass: #MDNetLocatorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'MC2-Tests-Repository-Network'!

!MDNetLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testDefaultPort
	| locator |
	locator := MDNetLocator host: 'source.wiresong.ca'.
	self assert: locator port = 6101! !

!MDNetLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testDescription
	| locator |
	locator := MDNetLocator host: 'source.wiresong.ca' port: 6101.
	self assert: locator description = 'source.wiresong.ca:6101'! !

!MDNetLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testDescriptionWithoutPort
	| locator |
	locator := MDNetLocator host: 'source.wiresong.ca'.
	self assert: locator description = 'source.wiresong.ca'! !

!MDNetLocatorTest methodsFor: 'as yet unclassified' stamp: 'cwp 5/22/2008 00:11'!
testHost
	| locator |
	locator := MDNetLocator host: 'source.wiresong.ca'.
	self assert: locator host = 'source.wiresong.ca'! !
